Layouts provide base templates that fits with specific use cases.

An example is `the standalone/focused.django.html` layout which
is perfect for pages with a single purpose such as login,
reset password, accept invite, etc.
